<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Nenhum
nenhum
Remover
(padrão)</translatorcomment>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translatorcomment>--exact match--
--file: pt.po--
Para comprimentos formatados como &apos;Engenharia&apos; ou &apos;Arquitetura&apos;, a unidade deve ser polegada.
Polegada</translatorcomment>
        <translation>Polegada</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fonte
Pé
Rodapé</translatorcomment>
        <translation>Pé</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Milha</translatorcomment>
        <translation>Milha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translatorcomment>--exact match--
--file: pt.po--
Milímetro
Milímetros</translatorcomment>
        <translation>Milímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translatorcomment>--exact match--
--file: pt.po--
Centímetro
Centímetros</translatorcomment>
        <translation>Centímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translatorcomment>--exact match--
--file: pt.po--
Comute o símbolo de diâmetro
Diâmetro (ø)</translatorcomment>
        <translation>Metro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Quilômetro</translatorcomment>
        <translation>Quilômetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Polegada Milimétrica</translatorcomment>
        <translation>Polegada Milimesimal</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
[0B80-0BFF] Tamês
Ladrilhado
Tâmil</translatorcomment>
        <translation>Milha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Jarda</translatorcomment>
        <translation>Jarda</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Ângstrom</translatorcomment>
        <translation>Ângstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Nanômetro</translatorcomment>
        <translation>Nanômetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Mícron</translatorcomment>
        <translation>Mícron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Decímetro</translatorcomment>
        <translation>Decímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Decâmetro</translatorcomment>
        <translation>Decâmetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Hectômetro</translatorcomment>
        <translation>Hectômetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Gigâmetro</translatorcomment>
        <translation>Gigâmetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Astro</translatorcomment>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Anos-Luz</translatorcomment>
        <translation>Ano-Luz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Parsec</translatorcomment>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+287"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pela Camada</translatorcomment>
        <translation>Pela Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pelo Carimbo</translatorcomment>
        <translation>Pelo Bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Refazer
Refaça a última ação</translatorcomment>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Amarelo
Definir cor do traço
Canal Amarelo</translatorcomment>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Verde
V&amp;erde:</translatorcomment>
        <translation>Verde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ciano
Definir cor do traço
Canal Ciano</translatorcomment>
        <translation>Ciano</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Azul
Função Azul
Remover Azul</translatorcomment>
        <translation>Azul</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Magenta
Definir cor do traço
Canal Magenta</translatorcomment>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Laranja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Vermelho Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Verde Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Azul Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Ciano Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Magenta Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Amarelo Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / Preto
Preto</translatorcomment>
        <translation>Preto</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Branco / Preto
Branco</translatorcomment>
        <translation>Branco</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
CInzento
Cinza
Cinza Claro</translatorcomment>
        <translation>Cinza</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Cinza Claro</translatorcomment>
        <translation>Cinza Claro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pt.ts--</translatorcomment>
        <translation>Outras...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>ID da Camada Atual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Unidade de Desenho</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Escala do Tipo de Linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Fonte da Fonte</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <source>Referenced Block</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bloco referenciado</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+93"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Indique a dimensão da linha de posicionamento ou insira o ângulo:
Indique a posição [ângulo/comprimento]</translatorcomment>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation>Pixel unidade</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: pt.po--
Encerrando o aplicativo...
Exportando o desenho...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Modifique
Modifique
&amp;Camada</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translatorcomment>Oculte (congele) todos os carimbos
Mostre (descongele) todos os carimbos
&amp;Horizontal</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Escalone
Escalone entidades</translatorcomment>
        <translation>Escala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Colunas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Linhas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Espaçamento de Coluna</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Espaçamento de Linha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+87"/>
        <location filename="../src/core/RObject.cpp" line="+66"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tipo de linha:
Tipo Ordinal</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-14"/>
        <source>Block</source>
        <translatorcomment>--exact match--
--file: Block_pt.ts--
&amp;Carimbo
Carimbo
Lista de Blocos</translatorcomment>
        <translation>Bloco</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+1"/>
        <source>Block ID</source>
        <translation>ID do Bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Camada
Lista de Camadas</translatorcomment>
        <translation>Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+99"/>
        <source>Linetype</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tipo de Linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Escala do tipo de linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Largura da Linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Cores
Abre diálogo de cores</translatorcomment>
        <translation>Cor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Cor exibida</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ordem do Desenho</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Contorno</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Manipulador</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Protegido</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Simples</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Posição do Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Texto Simples</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nome da Fonte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Altura do Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Ângulo do Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Escala X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Espaçamento entre Linhas</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Alinhamento</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotação</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Ver centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Ver alvo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Oculto</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Congelado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Guardada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Plotável</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Ajustável</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Inativo está congelado</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Ordem de tabulação</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Limites mínimo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Limites máximos</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Base de inserção</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Extensões mínimo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Extensões máximos</translation>
    </message>
    <message>
        <source>Plot Margins</source>
        <translation type="vanished">Margens de trama</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Foi detectada uma referência de bloco circular (recursiva):</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nome do bloco:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
        <source>Requires selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Requer uma seleção</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Nome</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Congelado</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Oculto</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Bloqueado</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Cor</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Tipo de Linha</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Espessura da Linha</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pela Camada</translatorcomment>
        <translation type="vanished">Pela Camada</translation>
    </message>
    <message>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pelo Carimbo</translatorcomment>
        <translation type="vanished">Pelo Bloco</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Contínuo</translatorcomment>
        <translation type="vanished">Contínuo</translation>
    </message>
    <message>
        <source>Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pontos de &amp;grade:
Pontilhado</translatorcomment>
        <translation type="vanished">Pontilhado</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pontilhado (pequeno)
Traço Ponto (pequeno)</translatorcomment>
        <translation type="vanished">Pontilhado (pequeno)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pontilhado (grande)
Traço Ponto (grande)</translatorcomment>
        <translation type="vanished">Pontilhado (grande)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tracejado
Tracejado (pequeno)</translatorcomment>
        <translation type="vanished">Tracejado</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tracejado (pequeno)</translatorcomment>
        <translation type="vanished">Tracejado (pequeno)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tracejado (grande)</translatorcomment>
        <translation type="vanished">Tracejado (grande)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Traço Ponto
Traço Ponto (pequeno)</translatorcomment>
        <translation type="vanished">Traço-Ponto</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Traço Ponto (pequeno)</translatorcomment>
        <translation type="vanished">Traço-Ponto (pequeno)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Traço Ponto (grande)</translatorcomment>
        <translation type="vanished">Traço-Ponto (grande)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Divida
Separação</translatorcomment>
        <translation type="vanished">Separação</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Separação (pequeno)</translatorcomment>
        <translation type="vanished">Separação (pequena)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Separação (grande)</translatorcomment>
        <translation type="vanished">Separação (grande)</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Centro, Ponto, Ângulos
Arco com Centro, Ponto, Ângulos</translatorcomment>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Centro (pequeno)</translatorcomment>
        <translation type="vanished">Centro (pequeno)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Centro (grande)</translatorcomment>
        <translation type="vanished">Centro (grande)</translation>
    </message>
    <message>
        <source>Border</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Limite
Borda
Borda (pequeno)</translatorcomment>
        <translation type="vanished">Margem</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Borda (pequeno)</translatorcomment>
        <translation type="vanished">Margem (pequena)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Borda (grande)</translatorcomment>
        <translation type="vanished">Margem (grande)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Métrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Textura</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Pela Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Pelo Bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Contínuo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Margem</translation>
    </message>
    <message>
        <source>Border (2x)</source>
        <translation type="vanished">Margem (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <source>Center (2x)</source>
        <translation type="vanished">Centro (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Traço-Ponto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Tracejado</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Divisor</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Pontilhado</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Oculto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Espectro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>traço ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO traço-espaço</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO Traço longo-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO Traço longo-ponto duplo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO Traço longo-ponto triplo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO Traço longo-traço curto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO Traço longo-traço curto duplo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO traço-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO traço duplo-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO traço-duplo ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO traço duplo-duplo ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO traço triplo-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO Traço duplo-ponto triplo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Fornecimento de Água Quente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Água Quente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Linha de Gás</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zigue Zague</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Trajetos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Linha de Cerca 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Linha de Cerca 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Drenagem</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Drenagem Reversa</translation>
    </message>
    <message>
        <source>Drainage Reverse</source>
        <translation type="vanished">Drenagem Reversa</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pela Camada</translatorcomment>
        <translation>Pela Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pelo Carimbo</translatorcomment>
        <translation>Pelo bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Unidade Padrão:
&amp;Padrões</translatorcomment>
        <translation>Padrão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,00mm</translatorcomment>
        <translation>0,00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,05mm</translatorcomment>
        <translation>0,05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,09mm</translatorcomment>
        <translation>0,09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,13mm (ISO)</translatorcomment>
        <translation>0,13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,15mm</translatorcomment>
        <translation>0,15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,18mm (ISO)</translatorcomment>
        <translation>0,18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,20mm</translatorcomment>
        <translation>0,20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,25mm (ISO)</translatorcomment>
        <translation>0,25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,30mm</translatorcomment>
        <translation>0,30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,35mm (ISO)</translatorcomment>
        <translation>0,35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,40mm</translatorcomment>
        <translation>0,40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,50mm (ISO)</translatorcomment>
        <translation>0,50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,53mm</translatorcomment>
        <translation>0,53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,60mm</translatorcomment>
        <translation>0,60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,70mm (ISO)</translatorcomment>
        <translation>0,70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,80mm</translatorcomment>
        <translation>0,80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
0,90mm</translatorcomment>
        <translation>0,90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
1,00mm (ISO)</translatorcomment>
        <translation>1,00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
1,06mm</translatorcomment>
        <translation>1,06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
1,20mm</translatorcomment>
        <translation>1,20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
1,40mm (ISO)</translatorcomment>
        <translation>1,40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
1,58mm</translatorcomment>
        <translation>1,58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
2,00mm (ISO)</translatorcomment>
        <translation>2,00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
2,11mm</translatorcomment>
        <translation>2,11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Customize..
Configurar...</translatorcomment>
        <translation type="vanished">Personalizado</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Tipo</translation>
    </message>
    <message>
        <source>Handle</source>
        <translatorcomment>--exact match--
--file: pt.po--
%1 ambíguo não tratado
Desenhar Alças
Mover manualmente</translatorcomment>
        <translation type="vanished">Manipulador</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Protegido</translation>
    </message>
</context>
</TS>
